@@ -955,9 +955,10 @@ class cognet:
                 f.writelines(["if __name__ == '__main__':\n",
                               "\twith MPIPoolExecutor() as executor:\n",
                               "\t\tresult = executor.map(dfunc_line, range(h))\n",
-                              "\t\tresult = np.array(result)\n",
-                              "\t\tresult = pd.DataFrame(np.maximum(result, result.transpose()))\n"
-                              "\t\tresult.to_csv(\'{}\',index=None,header=None)".format(OUTFILE)])
+                              "\tresult = pd.DataFrame(result)\n",
+	                          "\tresult = result.to_numpy()\n",
+                              "\tresult = pd.DataFrame(np.maximum(result, result.transpose()))\n"
+                              "\tresult.to_csv(\'{}\',index=None,header=None)".format(OUTFILE)])
                 
             with open(tmp_path+MPI_SETUP_FILE, 'w+') as ms:
                 ms.writelines(["#!/bin/bash\n",
